@@ -2,7 +2,7 @@ class Specinfra::Helper::DetectOs::Suse < Specinfra::Helper::DetectOs
   def detect
     if run_command('ls /etc/os-release').success? and run_command('zypper -V').success?
       line = run_command('cat /etc/os-release').stdout
-      if line =~ /ID=opensuse/
+      if line =~ /ID="?opensuse/
         family = 'opensuse'
       elsif line =~ /ID="sles"/
         family = 'sles'
